function P=gpm(v)
// Returns a permutation matrix according with a vector of desired permutation.
//
// Calling Sequence
//   gpm(v) // Show the permutation matrix calculated using the vector v. Always needs the parameter v.
//   d = gpm(v)
//
// Parameters
// v: Vector of desired permutation, that is the second-line vector in the two line representation of a permutation.
//
// Description
// This function gives the permutation matrix for a given permutation. Note that the entries on the vector must be less or equal to the size of the given vector and each one must appear only one time.
//
// Examples
// v=[2 3 1 4]
// M = gpm(v)
//
// Authors
//  Jorge Catumba ;

    r=size(v,"r")
    c=size(v,"c")
    if (r*c~=c & r*c~=r & typeof(v)~='constant') then
        error("Invalid input. Must be a constant vector.")
    else
        if (r>c) then
            v=v'
        end
        maxv=max(v)
        vcompare=1:maxv
        vsort=gsort(v,'c','i')
        if (or(vcompare~=vsort)) then
            error("Inconsistent permutation.")
        else
            P=zeros(maxv,maxv)
            for index=1:maxv
                P(v(1,index),index)=1
            end
        end
    end
endfunction