function H=pag(M,Vlist)
// Returns the adjacency matrix of the partition graph P of a graph G using the adjacency matrix of G graph.
//
// Calling Sequence
//   pag(M,Vlist)
//   H = pag(M,Vlist)
//
// Parameters
// M: Adjacency matrix of the initial graph G.
// Vlist: A list of the desired partition blocks, this is a list of vectors where each one contains the number of the nodes for each block.
//
// Description
// This function gives the adjacency matrix of the partition graph P of a graph G using the adjacency matrix of G graph
//
// Examples
// M=[0 0 3 1;0 0 2 0;1 1 0 1;3 0 0 0]
// Vlist=list([1,3],[2,4])
// H=pag(M,Vlist)
//
// See also
//  gpm
//  smb
//  influence
//  micmac
//  pagerank
//  pwp
//  heatkernel
//
// Authors
//  Jorge Catumba ;

    j=size(M,'c')
    vcompare=1:j
    sizelist=size(Vlist)
    sumsize=0
    uvect=[]
    permvect=[]
    realsize=[]
    difference=[]
    position=0
    
    for index=1:sizelist
        realsize(1,index)=size(Vlist(index),'c')
        uvect=union(uvect,Vlist(index))
        for indexj=1:realsize(index)
            position=position+1
            permvect(1,position)=Vlist(index)(indexj)
        end
    end
    
    sumsize=sum(realsize)
    sizepermvect=size(permvect,'c')
    sizeuvect=size(uvect,'c')
        
    if (sumsize>j | sizelist<=0 | sizeuvect~=sumsize | max(uvect)>j) then
        error('Incongruent partition.')
    else
        if (sizeuvect~=size(vcompare,'c')) then
            difference=setdiff(vcompare,permvect)
            for index=1:size(difference,'c')
                permvect(1,sizepermvect+index)=difference(1,index)
            end
        end
         permmat=gpm(permvect)
         permutedmatrix=permmat'*M*permmat
         newsize=size(Vlist)+size(difference,'c')
         while sum(realsize)<=j
             if (sum(realsize)~=j) then
                 sizerealsize=size(realsize,'c')
                 realsize(1,sizerealsize+1)=1
             else
                 break
             end
         end

         H=smb(permutedmatrix,realsize)
         for index=1:newsize
             H(index,index)=0
         end
    end
endfunction